Skip to contents

greta.gam is a module for greta that lets you use mgcv's smoother functions and formula syntax to define smooth terms for use in a greta model. You can then define your own likelihood to complete the model, and fit it by MCMC.

Author

Maintainer: Nicholas Tierney nicholas.tierney@gmail.com (ORCID)

Authors: