greta.gam: generalised additive models in greta using mgcv
Source:R/greta-gam-package.R
greta.gam.Rdgreta.gam is a module for greta that lets you use mgcv's smoother functions and formula syntax to define smooth terms for use in a greta model. You can then define your own likelihood to complete the model, and fit it by MCMC.
Author
Maintainer: Nicholas Tierney nicholas.tierney@gmail.com (ORCID)
Authors:
Nicholas Tierney nicholas.tierney@gmail.com (ORCID)
Nick Golding nick.golding.research@gmail.com (ORCID) [copyright holder]
David L Miller dave@ninepointeightone.net